==> jc-1.4.0.tar.gz: soot/jimple/spark/internal/AbstractTypeManager.h <==
// public abstract class soot.jimple.spark.internal.AbstractTypeManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_internal_AbstractTypeManager_H_
#define _JC_soot_jimple_spark_internal_AbstractTypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_FastHierarchy$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	_jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$refs	_jc_soot_jimple_spark_internal_AbstractTypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs	_jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object	_jc_soot_jimple_spark_internal_AbstractTypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtable	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$_init$47a8894d06f422db(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_internal_AbstractTypeManager$method$castNeverFails$397b37ee2b704c21(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *);
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
extern struct _jc_soot_FastHierarchy$object *_jc_soot_jimple_spark_internal_AbstractTypeManager$method$getFastHierarchy$759827438e6349fa(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$setFastHierarchy$e24bcfd8b2e91350(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_FastHierarchy$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$castNeverFails$397b37ee2b704c21;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$getFastHierarchy$759827438e6349fa;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$makeTypeMask$f36568e0574d6282;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$setFastHierarchy$e24bcfd8b2e91350;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods {
	jboolean	(*castNeverFails$397b37ee2b704c21)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *);
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
	struct _jc_soot_FastHierarchy$object	*(*getFastHierarchy$759827438e6349fa)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *);
	void	(*setFastHierarchy$e24bcfd8b2e91350)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_FastHierarchy$object *);
};

// Vtable
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs {
	struct _jc_soot_FastHierarchy$object	*fh;
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*pag;
	struct _jc_soot_util_queue_QueueReader$object	*allocNodeListener;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$refs {
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object {
	_jc_soot_jimple_spark_internal_AbstractTypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype _jc_soot_jimple_spark_internal_AbstractTypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_AbstractTypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_AbstractTypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_AbstractTypeManager_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/internal/AbstractTypeManager.h <==
// public abstract class soot.jimple.spark.internal.AbstractTypeManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b09f84837687f1ae soot_jimple_spark_internal_AbstractTypeManager

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_spark_internal_AbstractTypeManager_H_
#define _JC_soot_jimple_spark_internal_AbstractTypeManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_FastHierarchy$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_util_queue_QueueReader$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	_jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	_jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$refs	_jc_soot_jimple_spark_internal_AbstractTypeManager$refs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs	_jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs;
typedef struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object	_jc_soot_jimple_spark_internal_AbstractTypeManager$object;

typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods;
typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtable	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtable;
typedef const struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtype;

// Constructors
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$_init$47a8894d06f422db(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_internal_AbstractTypeManager$method$castNeverFails$397b37ee2b704c21(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$clearTypeMask$79fb55cc0b23cd6c(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_FastHierarchy$object *_jc_soot_jimple_spark_internal_AbstractTypeManager$method$getFastHierarchy$759827438e6349fa(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$makeTypeMask$f36568e0574d6282(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_internal_AbstractTypeManager$method$setFastHierarchy$e24bcfd8b2e91350(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_FastHierarchy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$castNeverFails$397b37ee2b704c21;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$clearTypeMask$79fb55cc0b23cd6c;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$getFastHierarchy$759827438e6349fa;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$makeTypeMask$f36568e0574d6282;
extern _jc_method _jc_soot_jimple_spark_internal_AbstractTypeManager$method_info$setFastHierarchy$e24bcfd8b2e91350;

// Virtual methods structure
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods {
	jboolean	(*castNeverFails$397b37ee2b704c21)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_Type$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	void	(*clearTypeMask$79fb55cc0b23cd6c)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
	struct _jc_soot_FastHierarchy$object	*(*getFastHierarchy$759827438e6349fa)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
	void	(*makeTypeMask$f36568e0574d6282)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *) _JC_JCNI_ATTR;
	void	(*setFastHierarchy$e24bcfd8b2e91350)(_jc_env *, struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object *, struct _jc_soot_FastHierarchy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vmethods	soot_jimple_spark_internal_AbstractTypeManager;
};

// Vtype
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs {
	struct _jc_soot_FastHierarchy$object	*fh;
	struct _jc_soot_jimple_spark_pag_AbstractPAG$object	*pag;
	struct _jc_soot_util_queue_QueueReader$object	*allocNodeListener;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$refs {
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_refs	soot_jimple_spark_internal_AbstractTypeManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_internal_AbstractTypeManager$sub_nonrefs	soot_jimple_spark_internal_AbstractTypeManager;
};

// Object instance structure
struct _jc_soot_jimple_spark_internal_AbstractTypeManager$object {
	_jc_soot_jimple_spark_internal_AbstractTypeManager$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$vtype	*vtype;
	_jc_soot_jimple_spark_internal_AbstractTypeManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_internal_AbstractTypeManager$vtype _jc_soot_jimple_spark_internal_AbstractTypeManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_internal_AbstractTypeManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_internal_AbstractTypeManager$class_object;

#endif	/* _JC_soot_jimple_spark_internal_AbstractTypeManager_H_ */
